@@ -479,8 +479,8 @@ class Database(object):
 				if not response.success: return response
 				old_format = Formats.get(self.content, serialize=True)
 				new_format = Formats.get(default, serialize=True)
-				if old_format != new_format:
-					return r3sponse.error(f"Mismatching formats, old format: {old_format}, new format: {new_format}.")
+				#if old_format != new_format:
+				#	return r3sponse.error(f"Mismatching formats, old format: {old_format}, new format: {new_format}.")
 				if new_format == "dict":
 					new = Dictionary(old).check(default=default, save=False)
 					print("NEW:",new,"VS",self.content,"=",new != Dictionary(self.content))
